@@ -3,7 +3,7 @@ import logging
 from django.conf import settings
 from django.db.models import DecimalField, Model, DateField
 
-from isc_common import delAttr, setAttr
+from isc_common import Wrapper
 from isc_common.common import blinkString
 from isc_common.fields.name_field import NameField
 from isc_common.fields.related import ForeignKeyProtect
@@ -14,13 +14,18 @@ from isc_common.number import DelProps, DecimalToStr
 from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item
+from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.production.models.launches import Launches
 from kaf_pas.production.models.operations import Operations
+from kaf_pas.production.models.resource import Resource
 from kaf_pas.sales.models.demand import Demand
 
 logger = logging.getLogger(__name__)
 
 
+class BWrapper(Wrapper):
+    pass
+
 class BufferQuerySet(AuditQuerySet):
     def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
         request = DSRequest(request=request)
@@ -111,6 +116,8 @@ class Buffers(Model):
     last_operation = ForeignKeyProtect(Operations, null=True, blank=True)
     last_operation_full_name = NameField(null=True, blank=True)
     launch = ForeignKeyProtect(Launches, null=True, blank=True)
+    resource = ForeignKeyProtect(Resource, null=True, blank=True)
+    location = ForeignKeyProtect(Locations, null=True, blank=True)
     location_code = NameField(null=True, blank=True)
     location_full_name = NameField(null=True, blank=True)
     value = DecimalField(decimal_places=4, max_digits=19)
