@@ -5,6 +5,7 @@ from django.db import transaction
 from django.forms import model_to_dict
 
 from isc_common import delAttr, setAttr
+from isc_common.common import new
 from isc_common.http.DSRequest import DSRequest
 from isc_common.number import DelProps
 from kaf_pas.planing.models.operation_resources import Operation_resources
@@ -86,7 +87,7 @@ class Write_off_itemsManager(OperationsManager):
         delAttr(_data, 'creator__short_name')
         delAttr(_data, 'status__name')
         setAttr(_data, 'opertype', settings.OPERS_TYPES_STACK.WRITE_OFF_TASK)
-        setAttr(_data, 'status', settings.OPERS_TYPES_STACK.WRITE_OFF_TASK_STATUSES.get('new'))
+        setAttr(_data, 'status', settings.OPERS_TYPES_STACK.WRITE_OFF_TASK_STATUSES.get(new))
         setAttr(_data, 'creator_id', user_id)
 
         with transaction.atomic():
@@ -99,8 +100,8 @@ class Write_off_itemsManager(OperationsManager):
                 setAttr(child, 'date', parent.date)
                 setAttr(child, 'creator_id', user_id)
                 setAttr(child, 'description', item.description)
-                setAttr(child, 'opertype', settings.OPERS_TYPES_STACK.CALC_DETAIL_MINUS_TASK)
-                setAttr(child, 'status', settings.OPERS_TYPES_STACK.CALC_DETAIL_MINUS_TASK_STATUSES.get('new'))
+                setAttr(child, 'opertype', settings.OPERS_TYPES_STACK.CALC_DETAIL_MNS_TASK)
+                setAttr(child, 'status', settings.OPERS_TYPES_STACK.CALC_DETAIL_MNS_TASK_STATUSES.get(new))
                 child = Operations.objects.create(**child)
 
                 Operation_refs.objects.create(parent=parent, child=child)
