@@ -31,26 +31,35 @@ class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
     def create(self, **kwargs):
         from kaf_pas.ckk.models.item_history import Item_history
 
-        res = super().create(**kwargs)
+        with transaction.atomic():
+            delAttr(kwargs, 'used')
 
-        delAttr(kwargs, 'id')
-        delAttr(kwargs, 'creator')
-        setAttr(kwargs, 'hcreator', res.creator)
-        setAttr(kwargs, 'item', res)
-        Item_history.objects.create(**kwargs)
-        return res
+            res = super().create(**kwargs)
+
+            delAttr(kwargs, 'id')
+            delAttr(kwargs, 'creator')
+            delAttr(kwargs, 'parent_id')
+            setAttr(kwargs, 'hcreator', res.creator)
+            setAttr(kwargs, 'item', res)
+            Item_history.objects.get_or_create(**kwargs)
+            return res
 
     def update(self, **kwargs):
         from kaf_pas.ckk.models.item_history import Item_history
 
-        res = super().update(**kwargs)
+        with transaction.atomic():
+            delAttr(kwargs, 'used')
 
-        delAttr(kwargs, 'id')
-        delAttr(kwargs, 'creator')
-        setAttr(kwargs, 'hcreator', res.creator)
-        setAttr(kwargs, 'item', res)
-        Item_history.objects.create(**kwargs)
-        return res
+            res = super().update(**kwargs)
+
+            delAttr(kwargs, 'id')
+            delAttr(kwargs, 'creator')
+            delAttr(kwargs, 'used')
+            setAttr(kwargs, 'hcreator', res.creator)
+            delAttr(kwargs, 'parent_id')
+            setAttr(kwargs, 'item', res)
+            Item_history.objects.get_or_create(**kwargs)
+            return res
 
 
 class ItemManager(CommonManagetWithLookUpFieldsManager):
@@ -80,6 +89,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         delAttr(_data, 'where_from')
         delAttr(_data, 'confirmed')
         setAttr(_data, 'props', props)
+        setAttr(_data, 'creator', request.user)
 
         res = super().create(**_data)
         logger.debug(f'Added: {res}')
@@ -100,11 +110,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
     @staticmethod
     def find_item(item):
-        item_query = None
         if isinstance(item, int):
             item = Item.objects.get(id=item)
         elif not isinstance(item, Item):
-            raise Exception(f'item must be Item or int')
+            raise Exception('item must be Item or int')
 
         STMP_2 = item.STMP_2.value_str if item.STMP_2 else None
         STMP_1 = item.STMP_1.value_str if item.STMP_1 else None
@@ -118,6 +127,53 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return [item for item in item_query]
 
+    @staticmethod
+    def find_item_contains(item):
+        if isinstance(item, int):
+            item = Item.objects.get(id=item)
+        elif not isinstance(item, Item):
+            raise Exception('item must be Item or int')
+
+        STMP_2 = item.STMP_2.value_str if item.STMP_2 else None
+        STMP_1 = item.STMP_1.value_str if item.STMP_1 else None
+
+        if STMP_2 == None:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
+        elif STMP_1 == None:
+            item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+        else:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+
+        return [item for item in item_query]
+
+    @staticmethod
+    def find_item1(**kwargs):
+        STMP_1 = kwargs.get('STMP_1')
+        STMP_2 = kwargs.get('STMP_2')
+
+        if STMP_2 == None:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1))
+        elif STMP_1 == None:
+            item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
+        else:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
+
+        return [item for item in item_query]
+
+    @staticmethod
+    def find_item1_contains(**kwargs):
+        STMP_1 = kwargs.get('STMP_1')
+        STMP_2 = kwargs.get('STMP_2')
+
+        if STMP_2 == None:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
+        elif STMP_1 == None:
+            item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+        else:
+            item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
+
+        return [item for item in item_query]
+
     @staticmethod
     def check_4_production(item):
         if isinstance(item, int):
@@ -125,14 +181,14 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         elif isinstance(item, Item):
             id = item.id
         else:
-            raise Exception(f'item must be Item or int')
+            raise Exception('item must be Item or int')
 
         with connection.cursor() as cursor:
-            cursor.execute(f'''select count(*) from ckk_item_not_typed_top_level_view
+            cursor.execute('''select count(*) from ckk_item_not_typed_top_level_view
                                 where parent_id = %s or child_id = %s''', [id, id])
             qty, = cursor.fetchone()
             if qty == 0:
-                cursor.execute(f'''select count(*) from ckk_item_typed_top_level_view
+                cursor.execute('''select count(*) from ckk_item_typed_top_level_view
                                     where parent_id = %s or child_id = %s''', [id, id])
                 qty, = cursor.fetchone()
             return qty > 0
@@ -144,6 +200,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         from kaf_pas.ckk.models.item_line import Item_line
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.production.models.operations_item import Operations_item
+        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
 
         key = 'ItemManager.delete_recursive'
         settings.LOCKS.acquire(key)
@@ -160,19 +217,17 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                                     FROM ckk_item_refs cir
                                                              join ckk_item cich on cich.id = cir.child_id
                                                     WHERE cir.child_id IN ({item_id})
-                                                      and cich.document_id = {document.id}
-                                                
+                                                        and cich.document_id = {document.id}
+
                                                     union all
-                                                
+
                                                     SELECT cir.*, r.level + 1 AS level
                                                     FROM ckk_item_refs cir
-                                                             join ckk_item cich on cich.id = cir.child_id
-                                                             JOIN r ON cir.parent_id = r.child_id
+                                                        join ckk_item cich on cich.id = cir.child_id
+                                                        JOIN r ON cir.parent_id = r.child_id
                                                     WHERE cich.document_id = {document.id}
                                                 )
-                                                
-                                                select *
-                                                from r'''
+                                                select * from r'''
         elif isinstance(document, Lotsman_documents_hierarcy):
             sql_text = f'''WITH RECURSIVE r AS (
                                                     SELECT cir.*, 1 AS level
@@ -189,9 +244,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                                              JOIN r ON cir.parent_id = r.child_id
                                                     WHERE cich.lotsman_document_id = {document.id}
                                                 )
-
-                                                select *
-                                                from r'''
+                                                select * from r'''
 
         cnt = Item_refs.objects.get_descendants_count(id=item_id, sql_text=sql_text)
 
@@ -205,12 +258,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                             Item_line.objects.filter(parent=item).delete()
                             item.delete()
                         else:
-                            _item = None
                             if progress != None:
                                 progress.setContentsLabel(f'''<h3>Удаление товарной позиции ({item.STMP_1.value_str if item.STMP_1 else ''} : {item.STMP_2.value_str if item.STMP_2 else ''}).</h3>''')
 
                             for item in Item_refs.objects.get_descendants(id=item_id, order_by_clause='order by level desc', sql_text=sql_text):
-                                _item = item
                                 _continue = False
                                 if soft_delete == None:
                                     if document != None:
@@ -234,6 +285,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                     # Ready_2_launch_detail.objects.filter(item=item.child_id).delete()
 
                                     Item_document.objects.filter(item_id=item.child_id).delete()
+
+                                    Tmp_Item_refsManager.create()
                                     Item.objects.filter(id=item.child_id).delete()
                                 else:
                                     if soft_delete == 'hide':
@@ -327,8 +380,6 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         if version != data.get('version'):
             setAttr(data, 'version', version)
 
-        res = Item.objects.filter(id=_data.get('id')).update(**data)
-
         return _data
 
     def updateFromRequest(self, request, removed=None, function=None):
@@ -457,7 +508,6 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                         settings.LOCKS.acquire(key)
                         for record in records:
                             id = record.get('id')
-                            parent_id = record.get('parent_id')
 
                             for item_line in Item_line.objects.filter(parent_id=id):
                                 item_refs, _ = Item_refs.objects.get_or_create(parent_id=id, child=item_line.child)
@@ -498,44 +548,31 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     def get_verstion(STMP_1, STMP_2, props, version=None, inc=1):
         key = 'ItemManager.get_verstion'
         settings.LOCKS.acquire(key)
+
+        if isinstance(STMP_1, int):
+            STMP_1 = Document_attributes.objects.get(id=STMP_1)
+
+        if isinstance(STMP_2, int):
+            STMP_2 = Document_attributes.objects.get(id=STMP_2)
+
         while True:
-            if isinstance(STMP_1, int):
-                STMP_1 = Document_attributes.objects.get(id=STMP_1)
+            query = Item.objects.filter(
+                STMP_1=STMP_1,
+                STMP_2=STMP_2,
+                props=props,
+                version=version
+            )
 
-            if isinstance(STMP_2, int):
-                STMP_2 = Document_attributes.objects.get(id=STMP_2)
-
-            if STMP_1 == None:
-                res = Item.objects.filter(
-                    STMP_1__isnull=True,
-                    STMP_2=STMP_2,
-                    props=props,
-                    version=version
-                )
-            elif STMP_2 == None:
-                res = Item.objects.filter(
-                    STMP_1=STMP_1,
-                    STMP_2__isnull=True,
-                    props=props,
-                    version=version
-                )
-            else:
-                res = Item.objects.filter(
-                    STMP_1=STMP_1,
-                    STMP_2=STMP_2,
-                    props=props,
-                    version=version
-                )
-
-            if len(res) == 0:
+            if query.count() == 0:
                 settings.LOCKS.release(key)
                 return version
             else:
-                version = res[0].version
+                version = query.order_by('-version')[0].version
                 if version == None:
                     version = 1
                 else:
                     version += inc
+                logger.debug(f'version: {version}')
 
     @staticmethod
     def getRecord(record):
@@ -584,7 +621,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 except ProgressDroped as ex:
                     Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
                     raise ex
-        raise Exception(f'Not data.')
+        raise Exception('Not data.')
 
     @staticmethod
     def _getQtyChilds(records):
@@ -594,18 +631,16 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         if isinstance(records, list):
             with connection.cursor() as cursor:
                 for record in records:
-                    cursor.execute(f'''WITH RECURSIVE r AS (
+                    cursor.execute('''WITH RECURSIVE r AS (
                                                                 SELECT *, 1 AS level
                                                                 FROM ckk_item_refs
                                                                 WHERE parent_id IN (%s)
-    
                                                                 union all
-    
                                                                 SELECT ckk_item_refs.*, r.level + 1 AS level
                                                                 FROM ckk_item_refs
                                                                          JOIN r
                                                                               ON ckk_item_refs.parent_id = r.child_id)
-    
+
                                                             select  count(*)
                                                             from r''', [record.get('id')])
                     qty, = cursor.fetchone()
