@@ -13,7 +13,8 @@ from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.base_ref import Hierarcy
 from isc_common.models.tree_audit import TreeAuditModelManager, TreeAuditModelQuerySet
-from isc_common.number import DelProps, ToDecimal, ToStr
+from isc_common.number import DelProps, ToStr
+from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.item import Item_add, Item
 from kaf_pas.ckk.models.item_line import Item_lineManager
 from kaf_pas.ckk.models.item_refs import Item_refsManager
@@ -67,6 +68,17 @@ class Item_viewQuerySet(TreeAuditModelQuerySet):
 
 class Item_viewManager(TreeAuditModelManager):
 
+    @staticmethod
+    def fullRows(suffix=''):
+        WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_item_view_grid}{suffix}')
+
+    @staticmethod
+    def refreshRows(ids):
+        if isinstance(ids, int):
+            ids = [ids]
+        records = [Item_viewManager.getRecord(record) for record in Item_viewManager.objects.filter(id__in=ids)]
+        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_item_view_grid_row, records=records)
+
     def updateFromRequest(self, request, removed=None, function=None):
         from kaf_pas.ckk.models.item_refs import Item_refs
 
