@@ -3,6 +3,7 @@ import logging
 from bitfield import BitField
 
 from clndr.models.calendars import Calendars
+from isc_common.fields.code_field import CodeField, CodeStrictField
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefQuerySet
@@ -31,6 +32,7 @@ class LocationsManager(CommonManagetWithLookUpFieldsManager):
             'code': record.code,
             'name': record.name,
             'full_name': record.full_name,
+            'color': record.color,
             'description': record.description,
             'parent_id': record.parent.id if record.parent else None,
             'calendar_id': record.calendar.id if record.calendar else None,
@@ -47,7 +49,9 @@ class LocationsManager(CommonManagetWithLookUpFieldsManager):
 
 
 class Locations(BaseRefHierarcy):
+    code = CodeStrictField(unique=True)
     calendar = ForeignKeyProtect(Calendars, null=True, blank=True)
+    color = CodeField()
     props = LocationsManager.props()
 
     objects = LocationsManager()
@@ -63,6 +67,16 @@ class Locations(BaseRefHierarcy):
         else:
             return None
 
+    @property
+    def is_workshop(self):
+        return self.props.isWorkshop.is_set
+
+    @property
+    def resource(self):
+        from kaf_pas.production.models.resource import Resource
+        resource, _ = Resource.objects.get_or_create(location_id=self.id, code='none', defaults=dict(name='Не определен'))
+        return resource
+
     @property
     def get_calendar(self):
         if self.calendar:
