@@ -1,6 +1,6 @@
 from django.urls import path
 
-from kaf_pas.ckk.views import item, material_type
+from kaf_pas.ckk.views import item
 
 urlpatterns = [
 
