@@ -1,9 +1,7 @@
 import logging
 
-from django.conf import settings
 from django.db import transaction
 from django.forms import model_to_dict
-from django.shortcuts import redirect
 
 from isc_common import delAttr, setAttr, Stack
 from isc_common.common.mat_views import create_tmp_table
@@ -11,9 +9,10 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
+from isc_common.isc.data_binding.criterion import Criterion
 from kaf_pas.ckk.models.combineItems import CombineItems
 from kaf_pas.ckk.models.copyItems import CopyItems
-from kaf_pas.ckk.models.item import Item
+from kaf_pas.ckk.models.item import Item, ItemManager
 from kaf_pas.ckk.models.item_line import Item_line
 from kaf_pas.ckk.models.item_operations_view import Item_operations_view, Item_operations_viewManager
 from kaf_pas.ckk.models.item_refs import Item_refs
@@ -31,11 +30,6 @@ lotsman_top_level = Contants.objects.update_or_create(code='lotsman_top_level',
 
 def get_excl():
     excluded = []
-    try:
-        # excluded = [int(item.value) for item in Contants.objects.filter(code__in=['audo_top_level'])]
-        excluded = []
-    except:
-        pass
     return excluded
 
 
@@ -66,9 +60,83 @@ def Item_view_Fetch(request):
             status=RPCResponseConstant.statusSuccess).response)
 
 
+class ItemCriterion(Criterion):
+    STMP_1__value_str = None
+    STMP_2__value_str = None
+
+
+@JsonResponseWithException()
+def Item_view_Variants_Fetch(request):
+    from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
+    from isc_common.isc.data_binding.advanced_criteria import AdvancedCriteria
+    from isc_common.isc.data_binding.criterion import Criterion
+    from isc_common.isc.data_binding.criteria_stack import CriteriaStack
+
+    _request = DSRequest(request=request)
+
+    criteria = _request.get_criteria()
+
+    if len(criteria) == 0:
+        criteria = [_request.get_data()]
+
+    res = CriteriaStack(criteria)
+    item = dict()
+
+    def get_item(criterion):
+        if isinstance(criterion, AdvancedCriteria):
+            for criterion in criterion.criteria:
+                if isinstance(criterion, AdvancedCriteria):
+                    get_item(criterion=criterion)
+                else:
+
+                    if isinstance(criterion, Criterion):
+                        if criterion.fieldName == 'STMP_1__value_str':
+                            item['STMP_1'] = criterion.value
+                        elif criterion.fieldName == 'STMP_2__value_str':
+                            item['STMP_2'] = criterion.value
+
+        elif isinstance(criterion, Criterion):
+            if criterion.fieldName == None:
+                item_criterion = ItemCriterion(**criterion.dict)
+
+                if item_criterion.STMP_1__value_str != None:
+                    item['STMP_1'] = item_criterion.STMP_1__value_str
+
+                if item_criterion.STMP_2__value_str != None:
+                    item['STMP_2'] = item_criterion.STMP_2__value_str
+
+            else:
+                if criterion.fieldName == 'STMP_1__value_str':
+                    item['STMP_1'] = criterion.value
+                elif criterion.fieldName == 'STMP_2__value_str':
+                    item['STMP_2'] = criterion.value
+
+    for criterion in res:
+        get_item(criterion)
+
+    if len(item) == 0:
+        item_refs = []
+    else:
+        items = ItemManager.find_item1_contains(**item)
+        item_refs_Stack = Item_refs_Stack()
+        item_refs = [row[0] for row in item_refs_Stack.add_childs(id=[a.id for a in items])]
+
+    return JsonResponse(
+        DSResponse(
+            request=request,
+            data=Item_view_query().
+                filter(refs_id__in=item_refs).
+                get_range_rows_variant(
+                request=request,
+                function=Item_viewManager.getRecord,
+                distinct_field_names=('id',)
+            ),
+            status=RPCResponseConstant.statusSuccess).response)
+
+
 @JsonResponseWithException()
 def Item_view_4_idFetch(request):
-    _request = DSRequest(request=request)
+    # _request = DSRequest(request=request)
     return JsonResponse(
         DSResponse(
             request=request,
@@ -119,11 +187,11 @@ def Item_view_Fetch2(request):
                     status=RPCResponseConstant.statusSuccess).response)
 
         id = data.get('launch_detail_id')
-        tmp_table_name = f'ready_2_launch_detail_tmp_table'
+        tmp_table_name = 'ready_2_launch_detail_tmp_table'
         create_tmp_table(
             on_commit=None,
             drop=False,
-            sql_str=f'''SELECT  t.*
+            sql_str='''SELECT  t.*
                                 FROM production_ready_2_launch_detail s
                                          CROSS JOIN LATERAL
                                     json_to_recordset(s.item_full_name_obj::json) as t(
@@ -238,60 +306,73 @@ class UploadDocumentTmpTable(UploadTmpTable):
 
 @JsonResponseWithException(printing=False)
 def Item_view_Fetch3(request):
-    from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
-    from kaf_pas.ckk.models.tmp_item_operations_view import Tmp_Item_operations_viewManager
+    from kaf_pas.kd.models.uploades_documents_view import Uploades_documents_view
+    from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
 
     _request = DSRequest(request=request)
     data = _request.get_data()
+    record = data.get('record')
+    if record != None:
+        id = record.get('id')
+    else:
+        id = data.get('id')
 
-    key = f'Item_view_Fetch3_{data.get("id")}'
-    if settings.LOCKS.locked(key):
-        redirect("http://ya.ru")
-    settings.LOCKS.acquire(key)
-    with transaction.atomic():
-        Tmp_Item_refsManager.create()
-        Tmp_Item_operations_viewManager.create()
+    items_set = set()
 
-        UploadTmpTable(data).make_tmp()
+    item_refs_Stack = Item_refs_Stack()
 
-        settings.LOCKS.release(key)
-        return JsonResponse(
-            DSResponse(
+    for uploades_documents in Uploades_documents_view.objects.filter(upload_id=id):
+        items = [item.id for item in Item.objects.filter(STMP_1=uploades_documents.STMP_1, STMP_2=uploades_documents.STMP_2)]
+        for item in items:
+            items_set.add(item)
+
+    item_refs = [row[0] for row in item_refs_Stack.add_childs(id=list(items_set))]
+
+    return JsonResponse(
+        DSResponse(
+            request=request,
+            data=Item_view_query().
+                filter(refs_id__in=item_refs).
+                get_range_rows_variant(
                 request=request,
-                data=Item_operations_view.objects.raw(
-                    raw_query=f'''select * from ckk_tmp_item_operations_view''',
-                    function=Tmp_Item_operations_viewManager.getRecord
-                ),
-                status=RPCResponseConstant.statusSuccess).response)
+                function=Item_viewManager.getRecord,
+                distinct_field_names=('id',)
+            ),
+            status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException(printing=False)
 def Item_view_Fetch4(request):
-    from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
-    from kaf_pas.ckk.models.tmp_item_operations_view import Tmp_Item_operations_viewManager
+    from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
 
     _request = DSRequest(request=request)
     data = _request.get_data()
+    record = data.get('record')
 
-    key = f'Item_view_Fetch4_{data.get("id")}'
-    if settings.LOCKS.locked(key):
-        redirect("http://ya.ru")
-    settings.LOCKS.acquire(key)
-    with transaction.atomic():
-        Tmp_Item_refsManager.create()
-        Tmp_Item_operations_viewManager.create()
+    if record == None:
+        id = data.get('id')
+        item = Item.objects.get(id=id)
+        STMP_1_id = item.STMP_1.id if item.STMP_1 else None
+        STMP_2_id = item.STMP_2.id if item.STMP_2 else None
+    else:
+        STMP_1_id = record.get('STMP_1_id')
+        STMP_2_id = record.get('STMP_2_id')
 
-        UploadDocumentTmpTable(data).make_tmp()
+    items = Item.objects.filter(STMP_1_id=STMP_1_id, STMP_2_id=STMP_2_id)
+    item_refs_Stack = Item_refs_Stack()
+    item_refs = [row[0] for row in item_refs_Stack.add_childs(id=[a.id for a in items])]
 
-        settings.LOCKS.release(key)
-        return JsonResponse(
-            DSResponse(
+    return JsonResponse(
+        DSResponse(
+            request=request,
+            data=Item_view_query().
+                filter(refs_id__in=item_refs).
+                get_range_rows_variant(
                 request=request,
-                data=Item_operations_view.objects.raw(
-                    raw_query=f'''select * from ckk_tmp_item_operations_view''',
-                    function=Tmp_Item_operations_viewManager.getRecord
-                ),
-                status=RPCResponseConstant.statusSuccess).response)
+                function=Item_viewManager.getRecord,
+                distinct_field_names=('id',)
+            ),
+            status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException(printing=False)
@@ -302,10 +383,8 @@ def Item_view_Fetch5(request):
     data = _request.get_data()
 
     with transaction.atomic():
-        from kaf_pas.planing.models.production_order_opers import Production_order_opersManager
-
         id = data.get('id')
-        tmp_table_name = f'production_order_tmp_table'
+        tmp_table_name = 'production_order_tmp_table'
 
         production_ext = Production_ext()
         production_ext.get_production_order_tmp_table(tmp_table_name=tmp_table_name, id=id)
