@@ -9,7 +9,7 @@ class EventStack:
     eventsManager = EventsManager()
 
     def __init__(self):
-        from kaf_pas.planing.models.operations import OperationEvent
+        from kaf_pas.planing.models.production_ext import OperationEvent
 
         self.EVENTS_TEST = self.eventsManager.get_event('events.test', 'События.Test', compulsory_reading=True)
 
