@@ -20,4 +20,10 @@ class GridCoonstant:
     refresh_production_buffers_grid = "refresh_production_buffers_grid"
     refresh_production_buffers_grid_row = "refresh_production_buffers_grid_row"
 
+    refresh_item_view_grid = "refresh_item_view_grid"
+    refresh_item_view_grid_row = "refresh_item_view_grid_row"
+
+    tmp_operation_value_view_grid = "tmp_operation_value_view_grid"
+    tmp_operation_value_view_grid_row = "tmp_operation_value_view_grid_row"
+
     lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"
