@@ -3,9 +3,6 @@ import logging
 from django.core.management import BaseCommand
 
 from isc_common.common.functions import delete_dbl_spaces
-from kaf_pas.ckk.models.item import Item
-from kaf_pas.ckk.models.item_view import Item_view
-from kaf_pas.kd.models.documents_ext import DocumentManagerExt
 
 logger = logging.getLogger(__name__)
 
