@@ -305,9 +305,9 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
                     lotsman_res += _lotsman_res
 
         if res > 0:
-            refresh_mat_view(mat_view_name='kd_documents_mview', progressStack=Progress(user=user_id, id='kd_documents_mview'))
+            refresh_mat_view(mat_view_name='kd_documents_mview')
         if lotsman_res > 0:
-            refresh_mat_view(mat_view_name='kd_lotsman_documents_hierarcy_mview', progressStack=Progress(user=user_id, id='kd_lotsman_documents_hierarcy_mview'))
+            refresh_mat_view(mat_view_name='kd_lotsman_documents_hierarcy_mview')
         return res
 
 
