@@ -68,7 +68,6 @@ class UploadesManager(AuditManager):
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.kd.models.uploades_log import Uploades_log
         from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
-        from kaf_pas.common.events_manager import EventStack
 
         # eventStack = EventStack()
 
@@ -197,7 +196,7 @@ class UploadesManager(AuditManager):
 
                     if continue_cnt == 0:
                         deleted = Uploades_log.objects.filter(upload_id=id).delete()
-                        # logger.debug(f'deleted: {deleted}')
+                        logger.debug(f'deleted: {deleted}')
                         if document_id == None:
                             res += Uploades.objects.filter(id=id).delete()[0]
                             # eventStack.EVENTS_DOWNLOAD_CONFIRM.send_message(message=progress.progresses.label_contents)
@@ -281,7 +280,7 @@ class UploadesManager(AuditManager):
                                 res += Item.objects.filter(lotsman_document=lotsman_documents_hierarcy).count()
 
                         if res == 0:
-                            raise Exception(f'Товарных позиций не найдено.')
+                            raise Exception('Товарных позиций не найдено.')
 
                         progress.setQty(qty=res)
                         if kind == 'confirm':
@@ -296,12 +295,13 @@ class UploadesManager(AuditManager):
                                 else:
                                     item.props &= ~Item.props.confirmed
 
-                                item.version == ItemManager.get_verstion(
+                                item.version = ItemManager.get_verstion(
                                     STMP_1=item.STMP_1,
                                     STMP_2=item.STMP_2,
                                     props=item.props
                                 )
                                 item.save()
+
                                 if progress.step() != 0:
                                     raise ProgressDroped
                                 logger.debug(f'progress.step() = {progress.cnt}')
