@@ -3,16 +3,16 @@ import logging
 from django.db.models import DecimalField, UniqueConstraint, Q
 
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.material_askon import Material_askon
 from kaf_pas.ckk.models.materials import Materials
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_materialQuerySet(AuditQuerySet):
+class Operation_materialQuerySet(BaseOperationQuerySet):
     pass
 
 
