@@ -3,13 +3,13 @@ import logging
 from django.db.models import TextField
 
 from isc_common.fields.related import ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
-from kaf_pas.planing.models.operations import Operations
+from isc_common.models.audit import AuditModel, AuditManager
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_noteQuerySet(AuditQuerySet):
+class Operation_noteQuerySet(BaseOperationQuerySet):
     pass
 
 
