@@ -1,17 +1,20 @@
 import copy
 import logging
+from decimal import Decimal
 
 from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
+from django.core.exceptions import EmptyResultSet
 from django.db import transaction, connection
 from django.db.models import DecimalField, DateTimeField, TextField, BooleanField, BigIntegerField, PositiveIntegerField
+from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr, Stack
 from isc_common.auth.models.user import User
 from isc_common.common import blinkString, started, new, doing
 from isc_common.common.functions import ExecuteStoredProc
 from isc_common.datetime import DateTimeToStr
-from isc_common.fields.code_field import CodeField
+from isc_common.fields.code_field import CodeField, JSONFieldIVC
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_manager import CommonManager
@@ -37,27 +40,45 @@ class Production_orderQuerySet(OperationsQuerySet):
             elif ToDecimal(this.value_start) == 0:
                 status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new)
             else:
-                status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(doing)
+                if ToDecimal(this.value_start) >= ToDecimal(this.value_sum):
+                    status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(doing)
+                else:
+                    status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(started)
 
             updated = super().filter(id=this.id).update(status=status)
             logger.debug(f'updated: {updated}')
             updated = Operations.objects.filter(id=this.id).update(status=status)
             logger.debug(f'updated: {updated}')
 
-    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
+    def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
+        queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
+
+        try:
+            logger.debug(f'\n\n{queryResult.query}\n')
+        except EmptyResultSet:
+            pass
+
+        if function:
+            from kaf_pas.ckk.models.locations_users import Locations_users
+            if not user.is_admin and not user.is_develop:
+                location_ids = list(map(lambda x: x.location.id, Locations_users.objects.filter(user=user)))
+            else:
+                location_ids = None
+            res = [function(record, location_ids) for record in queryResult]
+            return res
+        else:
+            res = [model_to_dict(record) for record in queryResult]
+            return res
+
+    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None, *args, **kwargs):
         request = DSRequest(request=request)
         data = request.get_data()
 
-        _data = data
+        _data = data.copy()
+
         delAttr(_data, 'arranged')
         delAttr(_data, 'location_id')
 
-        if data.get('location_id'):
-            _data = setAttr(_data, 'location_id', data.get('location_id'))
-
-        if data.get('launch_id'):
-            _data = setAttr(_data, 'launch_id', data.get('launch_id'))
-
         request.set_data(_data)
 
         self.alive_only = request.alive_only
@@ -69,7 +90,7 @@ class Production_orderQuerySet(OperationsQuerySet):
             distinct_field_names=distinct_field_names,
             json=request.json,
             criteria=request.get_criteria(),
-            user=request.user
+            user=request.user,
         )
         return res
 
@@ -202,10 +223,21 @@ class Production_orderQuerySet(OperationsQuerySet):
 
         request = DSRequest(request=request)
         data = request.get_data()
-        location_sector_id = data.get('location_sector_id')[0]
+
+        location_sector_ids = set()
+        for record in data.get('location_sector_ids'):
+            for location_sector_id in record:
+                location_sector_ids.add(location_sector_id)
+                break
+
+        if len(location_sector_ids) != 1:
+            location_sector_ids = []
+        else:
+            location_sector_ids = list(location_sector_ids)
+
         location_id = data.get('location_id')
 
-        parent_query = Locations_users.objects.filter(location_id=location_sector_id, user=request.user)
+        parent_query = Locations_users.objects.filter(location_id__in=location_sector_ids, user=request.user)
         parent = None
         if parent_query.count() > 0:
             parent = parent_query[0]
@@ -216,7 +248,7 @@ class Production_orderQuerySet(OperationsQuerySet):
                 parent = parent_query[0]
 
         res = [UserManager.getRecord1(item.user).get('id') for item in Locations_users.objects.filter(location_id=location_id, parent=parent)]
-        res1 = [UserManager.getRecord1(item.user).get('id') for item in Locations_users.objects.filter(location_id=location_sector_id)]
+        res1 = [UserManager.getRecord1(item.user).get('id') for item in Locations_users.objects.filter(location_id__in=location_sector_ids)]
 
         res2 = list(set(res).intersection(res1))
         return [UserManager.getRecord1(User.objects.get(id=id)) for id in res2]
@@ -444,7 +476,7 @@ class Production_orderManager(CommonManager):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_order_grid}{suffix}')
 
     @staticmethod
-    def getRecord(record):
+    def getRecord(record, location_ids=None):
 
         value_sum = ToDecimal(record.value_sum)
         if value_sum != 0:
@@ -453,6 +485,32 @@ class Production_orderManager(CommonManager):
             percents = 0
 
         percents_str = "%.2f" % percents
+        if location_ids:
+            ls_set = set(location_ids)
+            s_set = set(record.location_sector_ids)
+
+            if len(s_set.intersection(ls_set)) > 0:
+                status__name_arr = [record.location_statuses.get(str(location_id)) for location_id in location_ids]
+                status_id_arr = [record.location_status_ids.get(str(location_id)) for location_id in location_ids]
+
+                status_id = record.status.id if location_ids == None else status_id_arr[0] if len(status_id_arr) > 0 else None
+                status__name = record.status.name if location_ids == None else status__name_arr[0] if len(status__name_arr) > 0 else None
+            else:
+                status_id = record.status.id
+                status__name = record.status.name
+        else:
+            status_id = record.status.id
+            status__name = record.status.name
+
+        if isinstance(record.value1_sum, Decimal):
+            value1_sum = DecimalToStr(record.value1_sum)
+            value1_sum_len = 0
+        elif isinstance(record.value1_sum, list):
+            value1_sum = ' / '.join([DecimalToStr(v) for v in record.value1_sum]) if record.value1_sum != None else None
+            value1_sum_len = len(record.value1_sum) if record.value1_sum != None else None,
+        else:
+            value1_sum = '???'
+            value1_sum_len = 0
 
         res = {
             'creator__short_name': record.creator.get_short_name,
@@ -473,8 +531,8 @@ class Production_orderManager(CommonManager):
             'isFolder': record.isFolder,
             'cnt_opers': record.cnt_opers,
             'value_sum': DecimalToStr(record.value_sum),
-            'value1_sum': ' / '.join([DecimalToStr(v) for v in record.value1_sum]) if record.value1_sum != None else None,
-            'value1_sum_len': len(record.value1_sum) if record.value1_sum != None else None,
+            'value1_sum': value1_sum,
+            'value1_sum_len': value1_sum_len,
             'value_made': DecimalToStr(record.value_made),
             'value_made_str': f'''{blinkString(DecimalToStr(record.value_made), blink=True if percents >= 100 else False, color="blue", bold=True)}({percents_str}%)''',
             'value_start': DecimalToStr(record.value_start),
@@ -483,8 +541,8 @@ class Production_orderManager(CommonManager):
             'opertype_id': record.opertype.id,
             'parent_id': record.parent.id if record.parent else None,
             'status__code': record.status.code,
-            'status__name': blinkString(text=record.status.name, blink=False, color=record.status.color, bold=False),
-            'status_id': record.status.id,
+            'status__name': blinkString(text=status__name, blink=False, color=record.status.color, bold=False),
+            'status_id': status_id,
             'isDeleted': record.isDeleted,
         }
         return res
@@ -550,35 +608,32 @@ class Production_order(Hierarcy):
     from kaf_pas.planing.models.status_operation_types import Status_operation_types
     from kaf_pas.planing.models.operation_refs import Operation_refsManager
 
-    date = DateTimeField(default=None)
-    isFolder = BooleanField(default=None)
-    num = CodeField()
-
-    description = TextField(null=True, blank=True)
-
-    opertype = ForeignKeyProtect(Operation_types, related_name='Production_order_opertype')
-    creator = ForeignKeyProtect(User, related_name='Production_order_creator')
-    exucutors = ArrayField(BigIntegerField(), default=list)
-    location_sector_ids = ArrayField(BigIntegerField(), default=list)
-    location_sectors_full_name = ArrayField(TextField(), default=list)
     arranges_exucutors = ArrayField(BigIntegerField(), default=list)
-    status = ForeignKeyProtect(Status_operation_types)
+    cnt_opers = PositiveIntegerField()
+    creator = ForeignKeyProtect(User, related_name='Production_order_creator')
+    date = DateTimeField(default=None)
+    description = TextField(null=True, blank=True)
+    edizm_arr = ArrayField(CodeField(null=True, blank=True), default=list)
+    exucutors = ArrayField(BigIntegerField(), default=list)
+    isDeleted = BooleanField()
+    isFolder = BooleanField(default=None)
+    item = ForeignKeyProtect(Item, related_name='Production_order_item')
     launch = ForeignKeyCascade(Launches)
     location_ids = ArrayField(BigIntegerField(), default=list)
-    edizm_arr = ArrayField(CodeField(null=True, blank=True), default=list)
-    item = ForeignKeyProtect(Item, related_name='Production_order_item')
+    location_sector_ids = ArrayField(BigIntegerField(), default=list)
+    location_status_ids = JSONFieldIVC()
+    location_statuses = JSONFieldIVC()
+    location_sectors_full_name = ArrayField(TextField(), default=list)
+    num = CodeField()
+    opertype = ForeignKeyProtect(Operation_types, related_name='Production_order_opertype')
     parent_item = ForeignKeyProtect(Item, null=True, blank=True, related_name='Production_order_parent_item')
-    isDeleted = BooleanField()
-
-    cnt_opers = PositiveIntegerField()
-
-    value_sum = DecimalField(decimal_places=4, max_digits=19)
-    value1_sum = ArrayField(DecimalField(decimal_places=4, max_digits=19))
-    value_start = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
-    value_made = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
-    value_odd = DecimalField(decimal_places=4, max_digits=19)
-
     props = Operation_refsManager.props()
+    status = ForeignKeyProtect(Status_operation_types)
+    value1_sum = ArrayField(DecimalField(decimal_places=4, max_digits=19))
+    value_made = DecimalField(verbose_name='Количество  Выпущено', decimal_places=4, max_digits=19, null=True, blank=True)
+    value_odd = DecimalField(verbose_name='Количество  Выпущено', decimal_places=4, max_digits=19)
+    value_start = DecimalField(verbose_name='Количество Запущено', decimal_places=4, max_digits=19, null=True, blank=True)
+    value_sum = DecimalField(verbose_name='Количество по документации', decimal_places=4, max_digits=19)
 
     objects = Production_orderManager()
 
