@@ -14,7 +14,7 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_manager import CommonQuerySet, CommonManager
 from isc_common.models.audit import AuditModel
 from isc_common.models.standard_colors import Standard_colors
-from isc_common.number import DelProps, DecimalToStr, ToDecimal
+from isc_common.number import DelProps, DecimalToStr
 from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item
@@ -31,15 +31,15 @@ logger = logging.getLogger(__name__)
 
 
 class Production_order_opersQuerySet(CommonQuerySet):
-    def value_odd(self):
-        for this in self:
-            return ToDecimal(this.value_odd)
-        return 0
-
-    def value_odd_ship(self):
-        for this in self:
-            return ToDecimal(this.value_odd_ship)
-        return 0
+    # def value_odd(self):
+    #     for this in self:
+    #         return ToDecimal(this.value_odd)
+    #     return 0
+    #
+    # def value_odd_ship(self):
+    #     for this in self:
+    #         return ToDecimal(this.value_odd_ship)
+    #     return 0
 
     def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
         child_launch_id = json.get('data').get('child_launch_id')
@@ -127,6 +127,7 @@ class Production_order_opersManager(CommonManager):
             'isDeleted': record.isDeleted,
             'production_operation_is_transportation': record.production_operation_is_transportation,
             'production_operation_is_launched': record.production_operation_is_launched,
+            'production_operation_is_grouped': record.production_operation_is_grouped,
         }
         return DelProps(res)
 
@@ -152,6 +153,7 @@ class Production_order_opersManager(CommonManager):
         production_ext = Production_ext()
 
         data = request.get_data()
+
         production_ext.update_operation(data=data, user=request.user)
 
         return data
@@ -191,7 +193,6 @@ class Production_order_opers(AuditModel):
     description = TextField(null=True, blank=True)
     edizm_arr = ArrayField(CodeField(null=True, blank=True))
     isDeleted = BooleanField()
-    production_operation_is_absorption = BooleanField()
     item = ForeignKeyProtect(Item)
     launch = ForeignKeyProtect(Launches)
     location = ForeignKeyProtect(Locations, related_name='Production_order_opers_location')
@@ -206,6 +207,8 @@ class Production_order_opers(AuditModel):
     production_operation_color = ForeignKeyProtect(Standard_colors, null=True, blank=True)
     production_operation_colors = ArrayField(SmallIntegerField(null=True, blank=True))
     production_operation_edizm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
+    production_operation_is_absorption = BooleanField()
+    production_operation_is_grouped = BooleanField()
     production_operation_is_launched = BooleanField()
     production_operation_is_transportation = BooleanField()
     production_operation_num = PositiveIntegerField()
@@ -231,10 +234,67 @@ class Production_order_opers(AuditModel):
 
     @property
     def parent(self):
-        return Production_order_opers.objects.get(id=self.parent_id)
+        from kaf_pas.planing.models.production_order import Production_order
+        return Production_order.objects.get(id=self.parent_id)
+
+    @property
+    def left_neighbour(self):
+        if self.production_operation_num == 1:
+            return None
+
+        return self.all_childs[self.production_operation_num - 2]
+
+    @property
+    def right_neighbour(self):
+        if self.production_operation_num == len(self.all_childs):
+            return None
+        return self.all_childs[self.production_operation_num]
+
+    @property
+    def minus_operations(self):
+        from kaf_pas.planing.models.production_order_values import Production_order_values
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK
+
+        ids = map(lambda x: x.child, Operation_refs.objects.filter(parent_id=self.id, child__opertype__code=MADE_OPRS_MNS_TSK))
+        return Production_order_values.objects.filter(operation__in=ids).alive()
+
+    @property
+    def plus_operations(self):
+        from kaf_pas.planing.models.production_order_values import Production_order_values
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.operation_typesStack import MADE_OPRS_PLS_TSK
+
+        ids = map(lambda x: x.child, Operation_refs.objects.filter(parent_id=self.id, child__opertype__code=MADE_OPRS_PLS_TSK))
+        return Production_order_values.objects.filter(operation__in=ids).alive()
+
+    @property
+    def plus_grouped_operations(self):
+        from kaf_pas.planing.models.production_order_values import Production_order_values
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.operation_typesStack import GROUP_TSK
+
+        ids = map(lambda x: x.child, Operation_refs.objects.filter(parent_id=self.id, child__opertype__code=GROUP_TSK))
+        return Production_order_values.objects.filter(operation__in=ids).alive()
+
+    @property
+    def has_moving_operations(self):
+        return len(self.minus_operations) > 0 or len(self.plus_operations) or len(self.plus_grouping_operations) > 0
+
+    @property
+    def plus_grouping_operations(self):
+        from kaf_pas.planing.models.production_order_values import Production_order_values
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+
+        ids = map(lambda x: x.child, Operation_refs.objects.filter(parent_id=self.id, props=Operation_refs.props.product_making_block))
+        return Production_order_values.objects.filter(operation__in=ids).alive()
+
+    @property
+    def all_childs(self):
+        return Production_order_opers.objects.filter(parent_id=self.parent_id).alive().order_by('production_operation_num')
 
     def __str__(self):
-        return super().__str__()
+        return f'ID: {self.id}, production_operation: [{self.production_operation}]'
 
     def __repr__(self):
         return self.__str__()
