@@ -3,13 +3,13 @@ import logging
 from django.conf import settings
 from django.db.models import ProtectedError, Sum
 
-from isc_common import Stack, Wrapper
+from isc_common import Stack, Wrapper, delAttr
 from isc_common.common import blinkString, new
 from isc_common.datetime import DateToStr
 from isc_common.json import StrToJson
 from isc_common.number import DecimalToStr, Set, ToDecimal
 from kaf_pas.planing.models.production_order_values import Production_order_values
-from kaf_pas.planing.operation_typesStack import NoLaunch, MADE_OPRS_MNS_TSK
+from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK, MADE_OPRS_PLS_GRP_TSK
 
 logger = logging.getLogger(__name__)
 
@@ -49,6 +49,9 @@ class Production_orderWrapper(Wrapper):
     production_operation = None
     production_operation_attrs = None
     production_operation_color = None
+    production_operation_is_absorption = None
+    production_operation_is_launched = None
+    production_operation_is_grouped = None
     production_operation_colors = None
     production_operation_color_id = None
     production_operation_edizm = None
@@ -258,6 +261,7 @@ class Launch_release(Wrapper):
     # Последняя выполенная операция над деталью входящец в поглощающую операцию
     detal_last_operation = None
     launch = None
+    this_tech_operation = None
     location_fin = None
     operation_made = None
     production_order = None
@@ -315,26 +319,26 @@ class Production_order_values_ext:
             ) as progress:
                 with transaction.atomic():
                     def except_func():
-                        settings.LOCKS.release(key)
+                        settings.LOCKS.release(self.key_lock)
 
                     progress.except_func = except_func
 
                     operation_executor_stack = Operation_executor_stack()
                     for record in records:
-                        operation = Production_order.objects.get(id=record.get('id'))
+                        production_order = Production_order.objects.get(id=record.get('id'))
 
-                        key = f'''get_setStartStatus_{operation.id}'''
-                        settings.LOCKS.acquire(key)
+                        self.key_lock = f'''Production_order_values_{production_order.id}'''
+                        settings.LOCKS.acquire(self.key_lock)
 
                         edizm = Ed_izm.objects.get(code='шт')
                         _data = dict(
-                            id=operation.id,
-                            launch_id=operation.launch.id,
+                            id=production_order.id,
+                            launch_id=production_order.launch.id,
                             edizm_id=edizm.id
                         )
-                        qty = operation.value_sum
+                        qty = production_order.value_sum
 
-                        if operation.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new).id and operation.cnt_opers == 1:
+                        if production_order.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new).id and production_order.cnt_opers == 1:
                             production_ext.start(
                                 _data=_data,
                                 qty=qty,
@@ -343,12 +347,16 @@ class Production_order_values_ext:
                                 operation_executor_stack=operation_executor_stack
                             )
 
-                            setAttr(record, 'childs', [model_to_dict(production_order_opers) for production_order_opers in Production_order_opers.objects.filter(parent_id=operation.id)])
-                            setAttr(record, 'value', operation.value_sum)
+                            setAttr(record, 'childs', [model_to_dict(production_order_opers) for production_order_opers in Production_order_opers.objects.filter(parent_id=production_order.id)])
+                            setAttr(record, 'value', production_order.value_sum)
                             setAttr(record, 'edizm__name', edizm.name)
                             setAttr(record, 'edizm_id', edizm.id)
                             setAttr(record, 'value_start', qty)
 
+                            delAttr(record, 'launch_id')
+                            delAttr(record, 'launch__code')
+                            delAttr(record, 'launch__name')
+
                             res, _ = self.makeAll(
                                 data=record,
                                 user=user,
@@ -369,7 +377,7 @@ class Production_order_values_ext:
                             # END !!!!!!!!!!!!!!!!!!!! Не убирать !!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
                         if progress.step() != 0:
-                            settings.LOCKS.release(key)
+                            settings.LOCKS.release(self.key_lock)
                             raise ProgressDroped(progress_deleted)
 
             for operation_executor in operation_executor_stack:
@@ -378,7 +386,7 @@ class Production_order_values_ext:
                     users_array=[operation_executor.executor],
                 )
                 Production_orderManager.fullRows(suffix=f'''_user_id_{operation_executor.executor.id}''')
-            settings.LOCKS.release(key)
+            settings.LOCKS.release(self.key_lock)
             return _res
         else:
             raise Exception('Не сделан выбор.')
@@ -416,7 +424,7 @@ class Production_order_values_ext:
         # Связываем с операцией тезнологической операций поглощаемого элемента
         operation_refs, created = Operation_refs.objects.get_or_create(
             child=release_item_operation,
-            parent=launch_release.detal_last_operation.this,
+            parent=launch_release.detail_last_operation.this,
             props=Operation_refs.props.product_making
         )
         if created:
@@ -426,7 +434,6 @@ class Production_order_values_ext:
         from kaf_pas.production.models.launch_item_prod_order_view import Launch_item_order_view
         from kaf_pas.accounting.models.buffers import Buffers
         from kaf_pas.planing.models.production_order_opers_per_launch import Production_order_opers_per_launch
-        from kaf_pas.production.models.launches import Launches
 
         if launches_values.size() == 0:
             return
@@ -437,71 +444,92 @@ class Production_order_values_ext:
             launch_releases = list(launches_values.launch_releases(launch_id=launch_id))
 
             for launch_release in launch_releases:
+                launch = launch_release.launch if launch_release.launch.parent != None else launch_release.launch.child_launches[0]
+
                 for launch_item in Launch_item_order_view.objects.filter(parent=item):
                     logger.debug(f'launch_item: {launch_item}')
 
-                    launch = launch_release.launch if launch_release.launch.parent != None else Launches.objects.filter(parent=launch_release.launch)[0]
                     # Ищем составную часть в производственной спецификации для определения необходимого кол-во
                     launch_item_order_view = Launch_item_order_view.objects.filter(
                         item=launch_item.child,
                         launch_ids__overlap=[launch.id]
-                    )
+                    ).distinct().values('qty_per_one')
+
                     qty = launch_item_order_view.count()
 
                     if qty == 0:
                         raise Exception(f'Товарная позиция: {launch_item.child.item_name} не найдена в деталировке')
-                    elif qty == 1:
 
-                        qty_need = launch_item_order_view[0].qty_per_one * launch_release.value
-                        logger.debug(f'qty_need: {qty_need}')
+                    qty_need = launch_item_order_view[0].get('qty_per_one') * launch_release.value
+                    logger.debug(f'qty_need: {qty_need}')
 
-                        production_order_opers_per_launch = Production_order_opers_per_launch.objects.filter(item=launch_item.child, launch=launch).order_by("-operation_operation_num")[0]
-                        launch_release.detal_last_operation = production_order_opers_per_launch
-                        launch_release.resource = production_order_opers_per_launch.resource
-                        launch_release.resource_fin = production_order_opers_per_launch.resource_fin
-                        launch_release.location_fin = production_order_opers_per_launch.location_fin
-                        launch_release.item = production_order_opers_per_launch.item
-                        color = self.get_color(launch_release.color, production_order_opers_per_launch.production_operation)
-                        launch_release.color = color
+                    production_order_opers_per_launch = Production_order_opers_per_launch.objects.filter(item=launch_item.child, launch=launch).order_by("-operation_operation_num")[0]
+                    launch_release.detail_last_operation = production_order_opers_per_launch
+                    launch_release.resource = production_order_opers_per_launch.resource
+                    launch_release.resource_fin = production_order_opers_per_launch.resource_fin
+                    launch_release.location_fin = production_order_opers_per_launch.location_fin
+                    launch_release.item = production_order_opers_per_launch.item
 
-                        logger.debug(f'production_order_opers_per_launch.child: {production_order_opers_per_launch}')
+                    color = self.get_color(
+                        color=launch_release.color,
+                        # operation=production_order_opers_per_launch.production_operation,
+                        operation=launch_release.this_tech_operation,
+                        item=launch_item.child,
+                        launch=launch
+                    )
 
-                        buffers_query = Buffers.objects.filter(item=launch_item.child, launch=launch_release.launch, color=launch_item.color)
-                        cnt = buffers_query.count()
-                        if cnt == 1:
-                            exists_qty = buffers_query[0].value
-                            if exists_qty < qty_need:
-                                message = f'Недостаточно комплектации по: {launch_release.item.item_name}, в наличии {DecimalToStr(exists_qty)} а необходимо {DecimalToStr(qty_need)}'
-                                self.warnings.push(message)
+                    launch_release.color = color
 
-                        elif cnt == 0:
-                            message = f'Недостаточно комплектации по: {launch_release.item.item_name}, в наличии 0 а необходимо {DecimalToStr(qty_need)}'
+                    buffers_query = Buffers.objects.filter(item=launch_item.child, launch=launch, color=launch_release.color)
+                    cnt = buffers_query.count()
+                    if cnt == 1:
+                        exists_qty = buffers_query[0].value
+                        if exists_qty < qty_need:
+                            message = f'Недостаточно комплектации по: {launch_release.item.item_name}, в наличии {DecimalToStr(exists_qty)} а необходимо {DecimalToStr(qty_need)}'
                             self.warnings.push(message)
 
-                        else:
-                            raise Exception('Not clear situation.')
-
-                        self.rec_item_releases(
-                            launch_release=launch_release,
-                            value=qty_need,
-                            user=user
-                        )
+                    elif cnt == 0:
+                        message = f'Недостаточно комплектации по: {launch_release.item.item_name}, в наличии 0 а необходимо {DecimalToStr(qty_need)}'
+                        self.warnings.push(message)
 
                     else:
-                        raise Exception('Not clear situation.')
+                        raise Exception(f'{launch_item.child.item_name} для {launch.code} от {DateToStr(launch.date)}, цвет {launch_release.color.name} в буфере присутствует в двух местах.')
 
-    def get_color(self, color, operation):
+                    self.rec_item_releases(
+                        launch_release=launch_release,
+                        value=qty_need,
+                        user=user
+                    )
+
+    def get_color(self, color, operation, item=None, launch=None):
+        from kaf_pas.accounting.models.buffers import Buffers
         from isc_common.common.functions import ExecuteStoredProc
-        colors = ExecuteStoredProc('get_operation_colors', [operation.parent_id, operation.id])
 
-        if colors == None:
+        if operation != None and operation.production_operation_is_grouped:
+            color = None
+            for buffer_item in Buffers.objects.filter(item=item, launch=launch):
+                color = buffer_item.color
+                break
+            return color
+        elif operation != None and operation.production_operation_is_absorption:
+            color = None
+            for buffer_item in Buffers.objects.filter(item=item, launch=launch):
+                color = buffer_item.color
+                break
+            return color
+        elif operation != None:
+            colors = ExecuteStoredProc('get_operation_colors', [operation.parent_id, operation.id])
+
+            if colors == None:
+                return None
+
+            if color != None and isinstance(colors, list):
+                if color.id not in colors:
+                    color = None
+            return color
+        else:
             return None
 
-        if color != None and isinstance(colors, list):
-            if color.id not in colors:
-                color = None
-        return color
-
     def rec_launch_releases(
             self,
             prev_tech_operation,
@@ -590,17 +618,17 @@ class Production_order_values_ext:
 
     def rec_operation(
             self,
-            color,
             edizm,
             item,
-            location_fin,
             launch,
             opertype,
             resource,
-            resource_fin,
             status,
             value,
             user,
+            color=None,
+            location_fin=None,
+            resource_fin=None,
     ):
         from datetime import datetime
         from kaf_pas.planing.models.operation_color import Operation_color
@@ -696,7 +724,7 @@ class Production_order_values_ext:
 
         launches_values = Launch_releases()
 
-        if not this_tech_operation.production_operation.is_launched or data.launch == None:
+        if not this_tech_operation.production_operation_is_launched or data.launch == None:
 
             # Получаем список запусков связанных с заказами
             launches = self.get_launches(parent_launch=parent_launch, item=item)
@@ -743,11 +771,13 @@ class Production_order_values_ext:
                     break
 
         if min_value_made > 0:
+            launch = parent_launch if data.launch == None else data.launch
+
             this_plus_operation = self.rec_launch_releases(
                 color=data.color,
                 edizm=data.ed_izm,
                 item=item,
-                launch=parent_launch if data.launch == None else data.launch,
+                launch=launch,
                 prev_tech_operation=prev_tech_operation,
                 this_tech_operation=this_tech_operation,
                 user=user,
@@ -756,10 +786,11 @@ class Production_order_values_ext:
 
             launches_values.push(Launch_release(
                 operation_made=this_plus_operation,
+                this_tech_operation=this_tech_operation,
                 color=data.color,
                 edizm=data.ed_izm,
                 item=item,
-                launch=parent_launch,
+                launch=launch,
                 production_order=production_order,
                 value=min_value_made,
             ))
@@ -784,6 +815,112 @@ class Production_order_values_ext:
 
     warnings = Stack()
 
+    def rec_grouped(self, this_tech_operation, data, user):
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.models.tmp_operation_value import Tmp_operation_value
+        from kaf_pas.planing.models.tmp_operation_value import TMPOWrapper
+        from kaf_pas.planing.models.tmp_operation_value_view import Tmp_operation_value_view
+
+        plus_operations = Stack()
+        # Пишем группирующую операцию
+        group_operation = self.rec_operation(
+            edizm=data.ed_izm,
+            item=data.item,
+            launch=data.launch,
+            opertype=settings.OPERS_TYPES_STACK.GROUP_TASKS,
+            resource=this_tech_operation.resource,
+            status=settings.OPERS_TYPES_STACK.GROUP_TASKS_STATUSES.get(new),
+            value=data.value,
+            user=user,
+        )
+
+        # ===== Связываем с текущей технологической
+        operation_refs = Operation_refs.objects.create(
+            child=group_operation,
+            parent=this_tech_operation.this,
+            props=Operation_refs.props.product_making,
+        )
+        logger.debug(f'Created operation_refs :  {operation_refs}')
+
+        tmp_operations_query = Tmp_operation_value_view.objects. \
+            filter(user=user, launch=data.launch). \
+            values('id', 'value', 'color_id', 'edizm_id', 'launch_id', 'resource_id', 'parent_id', 'last_tech_operation_id'). \
+            exclude(value=None). \
+            exclude(value=0). \
+            distinct()
+
+        for tmp_operation in tmp_operations_query:
+
+            tmp_operation = TMPOWrapper(**tmp_operation)
+
+            previos_minus_operation = self.rec_operation(
+                color=tmp_operation.color,
+                edizm=tmp_operation.edizm,
+                item=tmp_operation.child,
+                launch=tmp_operation.launch,
+                opertype=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_MNS_TASK,
+                resource=tmp_operation.resource,
+                status=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_MNS_STATUSES.get(new),
+                value=tmp_operation.value,
+                user=user,
+            )
+            logger.debug(f'Created previos_minus_operation :  {previos_minus_operation}')
+
+            # ===== Связываем с предыдущей технологической
+            operation_refs = Operation_refs.objects.create(
+                child=previos_minus_operation,
+                parent=tmp_operation.last_tech_operation,
+                props=Operation_refs.props.product_making,
+            )
+            logger.debug(f'Created operation_refs :  {operation_refs}')
+
+            # Пишем прибавляющую (c признаком группировки) операцию
+            this_plus_operation = self.rec_operation(
+                color=tmp_operation.color,
+                edizm=tmp_operation.edizm,
+                item=tmp_operation.child,
+                launch=tmp_operation.launch,
+                opertype=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_PLS_GRP_TASK,
+                resource=tmp_operation.resource,
+                status=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_PLS_GRP_STATUSES.get(new),
+                value=tmp_operation.value,
+                user=user,
+            )
+            plus_operations.push(this_plus_operation)
+
+            logger.debug(f'Created launch_release_operation :  {this_plus_operation}')
+            # ===== Связываем с предыдущей технологической
+            operation_refs = Operation_refs.objects.create(
+                child=this_plus_operation,
+                parent=this_tech_operation.this,
+                props=Operation_refs.props.product_making,
+            )
+            logger.debug(f'Created operation_refs :  {operation_refs}')
+
+            # ===== Связываем операции вычитающую и прибавляющую чтобы потом удалять вместе
+            if previos_minus_operation:
+                operation_refs = Operation_refs.objects.create(
+                    child=this_plus_operation,
+                    parent=previos_minus_operation,
+                    props=Operation_refs.props.product_making,
+                )
+                logger.debug(f'Created operation_refs :  {operation_refs}')
+
+        # Связываем в блок раннее выполненые плюсовые операции
+        for plus_operation in plus_operations:
+            operation_refs = Operation_refs.objects.create(
+                child=plus_operation,
+                parent=group_operation,
+                props=Operation_refs.props.product_making_block,
+            )
+            logger.debug(f'Created operation_refs :  {operation_refs}')
+
+        # Удаляем временную таблицу группировочных данных
+        deleted = Tmp_operation_value.objects.filter(user=user, launch=data.launch).delete()
+        logger.debug(f'deleted:  {deleted}')
+
+    key_lock = None
+
     def makeAll(self, data, user, lock=True):
         from decimal import Decimal
         from django.conf import settings
@@ -793,7 +930,10 @@ class Production_order_values_ext:
         from isc_common.number import IntToDecimal
         from kaf_pas.planing.models.production_order_opers import Production_order_opers
         from kaf_pas.planing.models.production_order_values import Production_order_valuesManager
-        from kaf_pas.planing.models.production_order_opers_per_launch import Production_order_opers_per_launch
+        from kaf_pas.accounting.models.buffers import Buffers
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.models.operation_item import Operation_item
+        from kaf_pas.planing.models.operation_value import Operation_value
 
         self.warnings.clear()
 
@@ -823,9 +963,9 @@ class Production_order_values_ext:
         # Все операции технологичской цепочки
         all_operations = list(Production_order_opers.objects.filter(parent_id=production_order.id, deleted_at=None).order_by('production_operation_num'))  # !! Не менять на parent  у Production_order_opers его нет, есть тольо parent_id
 
-        key = f'Production_order_valuesManager.makeAll_{production_order.id}'
+        self.key_lock = f'Production_order_values_{production_order.id}'
         if lock:
-            settings.LOCKS.acquire(key)
+            settings.LOCKS.acquire(self.key_lock)
 
         try:
             # ========================================Проверяем заполнение предыдущей операции===================================================
@@ -837,14 +977,14 @@ class Production_order_values_ext:
                     value_enabled = value_previos - value_curent
                     if value_enabled < value:
                         if lock:
-                            settings.LOCKS.release(key)
+                            settings.LOCKS.release(self.key_lock)
                         raise Exception(f'Не достаточно выпуска в предыдущей операции № п/п {operation.production_operation_num}. Возможное количество {DecimalToStr(value_enabled)}')
 
                     if data.color != None:
                         value_on_coors = ExecuteStoredProc('get_operation_colors_qty1', [production_order.id, first_production_order_oper.id, data.color.id])
                         if value_on_coors != None and ToDecimal(value_on_coors) < value:
                             if lock:
-                                settings.LOCKS.release(key)
+                                settings.LOCKS.release(self.key_lock)
                             Production_order_valuesManager.fullRows()
                             raise Exception(f'Не достаточно изделий данного цвета. Возможное количество {DecimalToStr(value_on_coors)}')
 
@@ -857,7 +997,7 @@ class Production_order_values_ext:
                 if old_num != None:
                     if old_num != operation.production_operation_num - 1:
                         if lock:
-                            settings.LOCKS.release(key)
+                            settings.LOCKS.release(self.key_lock)
                         raise Exception('Выбран не сплошной сегмент операций.')
                 old_num = operation.production_operation_num
             # ===================================================================================================================================
@@ -869,7 +1009,7 @@ class Production_order_values_ext:
 
             if min_value_made < value:
                 if lock:
-                    settings.LOCKS.release(key)
+                    settings.LOCKS.release(self.key_lock)
                 Production_order_valuesManager.fullRows()
                 raise Exception(f'Превышение количества остатка (Запущено - Выполнено). Максимально возможное: {DecimalToStr(min_value_made)}')
             else:
@@ -880,58 +1020,88 @@ class Production_order_values_ext:
             first_step = True
 
             for operation in operations:
-                # Получаем предыдущую техноглогическую операцию
-                prev_tech_operation = self.get_prev_tech_operation(
-                    production_operation_num=operation.production_operation_num,
-                    production_order=production_order
-                )
 
-                do_rec_items_releases = False
-                # Вычисляем необходимость вычета комплектующих если эта операция поглощающая
-                if do_rec_items_releases == False and operation.production_operation.is_absorption:
-                    do_rec_items_releases = True
+                if not operation.production_operation_is_grouped and operation.production_operation_is_launched and first_step:
+                    color = data.color
+                    if data.color != None:
+                        value_odd = ToDecimal(Buffers.objects.filter(item=item, launch=data.launch, color=data.color, last_operation=all_operations[operation.production_operation_num - 2].production_operation).aggregate(Sum('value')).get('value__sum'))
+                        if value_odd == 0:
+                            color = None
+                            value_odd = ToDecimal(Buffers.objects.filter(item=item, launch=data.launch, last_operation=all_operations[operation.production_operation_num - 2].production_operation).aggregate(Sum('value')).get('value__sum'))
 
-                # или последняя в технологической цепочке
-                # Необходимость выполнеия отгрузки
-                if operation.production_operation_num == all_operations[-1].production_operation_num:
-                    r = list(filter(lambda x: x.production_operation.is_absorption, filter(lambda x: x.production_operation_num != operation.production_operation_num, all_operations)))
-                    do_rec_items_releases = len(r) == 0
-                    # do_rec_order_releases = True
-
-                if operation.production_operation.is_launched and data.launch != None and first_step:
-                    if data.launch.code == NoLaunch:
-                        value_odd = value
                     else:
-                        value_odd = Production_order_opers_per_launch.objects.filter(
-                            parent_id=production_order.id,
-                            launch=data.launch,
-                            production_operation=operation.production_operation).value_odd()
+                        value_odd = ToDecimal(Buffers.objects.filter(item=item, launch=data.launch, last_operation=all_operations[operation.production_operation_num - 2].production_operation).aggregate(Sum('value')).get('value__sum'))
 
                     first_step = False
                     if value_odd < value:
-                        if data.color != None:
+                        if color == None:
                             raise Exception(f'Превышение остатка, по запуску {data.launch.code} от {DateToStr(data.launch.date)}, в операции {operation.production_operation.full_name}, возможное количество: {DecimalToStr(value_odd)}')
                         else:
-                            raise Exception(f'Превышение остатка, по запуску {data.launch.code} от {DateToStr(data.launch.date)}, в операции {operation.production_operation.full_name}, возможное количество: {DecimalToStr(value_odd)}')
+                            raise Exception(f'Превышение остатка, по запуску {data.launch.code} от {DateToStr(data.launch.date)}, цвет: {color.name} в операции {operation.production_operation.full_name}, возможное количество: {DecimalToStr(value_odd)}')
 
-                # Записываем действия по выполнению
-                self.make_launch_release(
-                    prev_tech_operation=prev_tech_operation,
-                    this_tech_operation=operation,
-                    data=data,
-                    item=item,
-                    production_order=production_order,
-                    min_value_made=min_value_made,
-                    parent_launch=parent_launch,
-                    user=user,
-                    do_rec_items_releases=do_rec_items_releases,
-                    # do_rec_order_releases=do_rec_order_releases,
-                )
+                # Записываем действия по группировке
+                if operation.production_operation_is_grouped:
+                    self.rec_grouped(
+                        this_tech_operation=operation,
+                        data=data,
+                        user=user,
+                    )
+                else:
+                    # Получаем предыдущую техноглогическую операцию
+                    prev_tech_operation = self.get_prev_tech_operation(
+                        production_operation_num=operation.production_operation_num,
+                        production_order=production_order
+                    )
+
+                    do_rec_items_releases = operation.production_operation.is_absorption
+
+                    # Записываем действия по выполнению если предыдущая технологическая операция была групирующей
+                    if prev_tech_operation != None and prev_tech_operation.production_operation_is_grouped:
+                        # Ищем главную группирующую
+
+                        for grouped_operation in prev_tech_operation.plus_grouped_operations:
+                            # Открываем блок сгруппированных
+
+                            grouping_operations = map(lambda x: x.child, Operation_refs.objects.filter(parent=grouped_operation.operation, props=Operation_refs.props.product_making_block))
+
+                            for grouping_operation in grouping_operations:
+                                operation_value = Operation_value.objects.get(operation=grouping_operation)
+
+                                operation_item = Operation_item.objects.get(operation=operation_value.operation)
+                                logger.debug(f'item ID: {operation_item.item.id}, {operation_item.item.item_name}')
+
+                                # Записываем действия по выполнению
+                                self.make_launch_release(
+                                    prev_tech_operation=prev_tech_operation,
+                                    this_tech_operation=operation,
+                                    data=data,
+                                    item=operation_item.item,
+                                    production_order=production_order,
+                                    min_value_made=operation_value.value,
+                                    parent_launch=parent_launch,
+                                    user=user,
+                                    do_rec_items_releases=do_rec_items_releases,
+                                    # do_rec_order_releases=do_rec_order_releases,
+                                )
+
+                    # Записываем действия по выполнению
+                    self.make_launch_release(
+                        prev_tech_operation=prev_tech_operation,
+                        this_tech_operation=operation,
+                        data=data,
+                        item=item,
+                        production_order=production_order,
+                        min_value_made=min_value_made,
+                        parent_launch=parent_launch,
+                        user=user,
+                        do_rec_items_releases=do_rec_items_releases,
+                        # do_rec_order_releases=do_rec_order_releases,
+                    )
 
             # ===================================================================================================================================
 
             if lock:
-                settings.LOCKS.release(key)
+                settings.LOCKS.release(self.key_lock)
 
             # выводим предупридительные сообщения, или прекращаем выполнение оперраций
             if self.warnings.size() > 0:
@@ -949,7 +1119,7 @@ class Production_order_values_ext:
 
         except Exception as ex:
             if lock:
-                settings.LOCKS.release(key)
+                settings.LOCKS.release(self.key_lock)
                 Production_order_valuesManager.fullRows()
             raise ex
 
@@ -977,6 +1147,16 @@ class Production_order_values_ext:
             deleted = operation_ref.parent.delete()
             logger.debug(f'deleted: {deleted}')
 
+    def delete_operations(self, operation, check=True):
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+
+        for operation_ref in Operation_refs.objects.filter(parent=operation, props=Operation_refs.props.product_making_block):
+            operation_ref.delete()
+            self.delete_operation(operation=operation_ref.child, check=False)
+            operation_ref.child.delete()
+
+        self.delete_operation(operation=operation, check=check)
+
     def delete_operation(self, operation, check=True):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         from kaf_pas.planing.operation_typesStack import DETAIL_OPERS_PRD_TSK, MADE_OPRS_PLS_TSK, PRD_TSK
@@ -985,24 +1165,23 @@ class Production_order_values_ext:
         if check:
             parent = Operation_refs.objects.filter(child=operation, parent__opertype__code__in=[DETAIL_OPERS_PRD_TSK])[0].parent
             detail_order_opers_operation = Production_order_opers.objects.get(id=parent.id)
-            value_made = detail_order_opers_operation.value_made
+            value_made = ToDecimal(Production_order_opers.objects.filter(id=parent.id).aggregate(Sum('value_made')).get('value_made__sum'))
 
-            value_query = Production_order_values.objects.filter(id=operation.id, opertype__code__in=[MADE_OPRS_PLS_TSK])
-            if value_query.count() > 0:
-                value = value_query[0].value
-            else:
-                value = 0
+            value = ToDecimal(Production_order_values.objects.filter(id=operation.id, opertype__code__in=[MADE_OPRS_PLS_TSK]).aggregate(Sum('value')).get('value__sum'))
 
             order_operation = Operation_refs.objects.filter(child=parent, parent__opertype__code__in=[PRD_TSK])[0].parent
             detail_order_opers_operations = [Production_order_opers.objects.get(id=operation_refs.child.id) for operation_refs in Operation_refs.objects.filter(parent=order_operation, child__opertype__code__in=[DETAIL_OPERS_PRD_TSK])]
             detail_order_opers_operation_next = [dt for dt in detail_order_opers_operations if dt.production_operation_num == detail_order_opers_operation.production_operation_num + 1]
-            value_made_next = detail_order_opers_operation_next[0].value_made if len(detail_order_opers_operation_next) > 0 else 0
 
-            if value_made - value_made_next < value:
-                raise Exception(f'Сумму: {DecimalToStr(value)} удалить не могу т.к. она уже была использована в последующей операции. Максимально возможная сумма к удалению {DecimalToStr(value_made - value_made_next)}')
+            value_made_next = 0
+            for detail_order_opers_oper in detail_order_opers_operation_next:
+                value_made_next += detail_order_opers_oper.value_made
+
+            value_enabled = value_made - value_made_next
+            if value_enabled < value:
+                raise Exception(f'Сумму: {DecimalToStr(value)} удалить не могу т.к. она уже была использована в последующей операции. Максимально возможная сумма к удалению {DecimalToStr(value_enabled)}')
 
         # Связи с релизами
-        # RELEASE_TSK_PLS - выпуск изделия
         # MADE_OPRS_MNS_TSK - расход комплектующих
         for release_items in Operation_refs.objects.filter(parent=operation, child__opertype__code__in=[MADE_OPRS_MNS_TSK]):
             deleted = release_items.delete()
@@ -1032,15 +1211,24 @@ class Production_order_values_ext:
 
     def delete_sums(self, operations, func_refreshed=None, parent=None):
         from django.conf import settings
+        from kaf_pas.planing.models.operations import Operations
 
         res = 0
 
         for operation in operations:
-            key = f'Production_order_valuesManager.delete_sums_{operation.id}'
-            try:
-                settings.LOCKS.acquire(key)
 
-                self.delete_operation(operation=operation)
+            if isinstance(parent, Operations):
+                self.key_lock = f'Production_order_values_{parent.id}'
+            elif isinstance(parent, dict):
+                parent = Operations.objects.get(id=parent.get('id'))
+                self.key_lock = f'Production_order_values_{parent.id}'
+            else:
+                self.key_lock = f'Production_order_values_delete_sums'
+
+            try:
+                settings.LOCKS.acquire(self.key_lock)
+
+                self.delete_operations(operation=operation)
 
                 deleted, _ = operation.delete()
                 res += deleted
@@ -1048,14 +1236,14 @@ class Production_order_values_ext:
                 if callable(func_refreshed):
                     func_refreshed()
 
-                settings.LOCKS.release(key)
+                settings.LOCKS.release(self.key_lock)
 
             except ProtectedError as ex:
-                settings.LOCKS.release(key)
+                settings.LOCKS.release(self.key_lock)
                 raise ex
 
             except Exception as ex:
-                settings.LOCKS.release(key)
+                settings.LOCKS.release(self.key_lock)
                 raise ex
 
         return res
