@@ -83,8 +83,8 @@ class Routing_ext:
                 ],
                 level_id=level_id
             ).
-            values('location_id', 'location__name').
-            distinct()
+                values('location_id', 'location__name').
+                distinct()
         ],
             key=lambda x: x['title'])
 
@@ -101,7 +101,7 @@ class Routing_ext:
                 prompt=f'''ID: {operation.get('resource_id')}, {operation.get('resource__description')}''',
             )
             for operation in Operation_resources_view.objects.
-            filter(
+                filter(
                 launch_id=launch_id,
                 level_id=level_id,
                 location_id=location_id,
@@ -150,6 +150,7 @@ class Routing_ext:
         from kaf_pas.production.models.launches import Launches
         from kaf_pas.ckk.models.ed_izm import Ed_izm
         from kaf_pas.production.models.launches_view import Launches_viewManager
+        from kaf_pas.ckk.models.item import Item
 
         logger.debug(f'data: {data}')
 
@@ -327,7 +328,7 @@ class Routing_ext:
                                     first_operation = None
 
                                     # Выполняем маршрутизацию внутри товарной позиции согласно порядку выплонения оперций из production
-                                    cnt1 = Launch_operations_item.objects.filter(item_id=child_id, launch_id=launch_id).count()
+                                    cnt1 = Launch_operations_item.objects.filter(item_id=child_id, launch_id=launch_id).alive().count()
                                     if cnt1 > 0:
                                         for launch_operations_item in Launch_operations_item.objects.filter(item_id=child_id, launch_id=launch_id).order_by('num'):
 
@@ -357,12 +358,12 @@ class Routing_ext:
                                             logger.debug(f'Created operation_item_add :  {operation_item_add}')
 
                                             operation_operation = Operation_operation.objects.create(
+                                                color=launch_operations_item.color,
+                                                creator=user,
                                                 ed_izm=launch_operations_item.ed_izm,
                                                 num=launch_operations_item.num,
                                                 operation=outcome_operation,
                                                 production_operation=launch_operations_item.operation,
-                                                color=launch_operations_item.color,
-                                                creator=user,
                                                 qty=launch_operations_item.qty,
                                             )
                                             logger.debug(f'Created operation_operation :  {operation_operation}')
@@ -473,7 +474,7 @@ class Routing_ext:
                                     parent_id = child_id
                                 parent_item = routed_items.find_one(lambda item: item.item_id == parent_id)
                             except StackElementNotExist:
-                                message = 'Товарная позиция не обнаружена среди товарных позиций, прошедших внутреннюю маршрутизацию. Запустите анализатор готовности,и проверьте какая-то сборочная Единица стоит в разделе документации.'
+                                message = f'{Item.objects.get(id=parent_id).item_name} (ID={parent_id}),  не обнаружена среди товарных позиций, прошедших внутреннюю маршрутизацию. Запустите анализатор готовности,и проверьте какая-то сборочная Единица стоит в разделе документации.'
                                 mess2 = ''
                                 operation_item_add = Operation_item_add.objects.filter(item_id=child_id)
                                 if operation_item_add.count() > 0:
