@@ -32,7 +32,7 @@ class Launch_item_viewManager(AuditManager):
         if isinstance(item, int):
             item = Item.objects.get(id=item)
         elif not isinstance(item, Item):
-            raise Exception(f'item must be Item or int')
+            raise Exception('item must be Item or int')
 
         STMP_2 = item.STMP_2.value_str if item.STMP_2 else None
         STMP_1 = item.STMP_1.value_str if item.STMP_1 else None
@@ -58,8 +58,10 @@ class Launch_item_viewManager(AuditManager):
 
     @staticmethod
     def check_launch(launch):
-        if launch.status.code != 'formirovanie':
-            raise Exception(f'''Редактирование допускается только при статусе "Формирование"''')
+        from django.conf import settings
+        if not settings.DEBUG:
+            if launch.status.code != 'formirovanie':
+                raise Exception('''Редактирование допускается только при статусе "Формирование"''')
 
     @staticmethod
     def getRecord(record):
@@ -92,7 +94,6 @@ class Launch_item_viewManager(AuditManager):
         from kaf_pas.production.models.launch_item_refs import Launch_item_refs
         request = DSRequest(request=request)
         data = request.get_data()
-        _data = data.copy()
 
         Launch_item_viewManager.check_launch(launch=Launch_item_refs.objects.get(id=data.get('item_refs_id')).launch)
 
@@ -112,6 +113,8 @@ class Launch_item_viewManager(AuditManager):
             for id, mode in tuple_ids:
                 if mode == 'hide':
                     super().filter(id=id).soft_delete()
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
                 else:
                     Launch_item_viewManager.check_launch(launch=Launch_item_view.objects.get(id=id).launch)
                     qty, _ = super().filter(id=id).delete()
