@@ -45,7 +45,7 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
     def get_props():
         return BitField(flags=(
             ('launched', 'Возможность привязки к запуску'),  # 0
-            ('no_used', 'Не используется'),  # 1
+            ('grouped', 'Группировка'),  # 1
             ('transportation', 'Операция транспортировки'),  # 2
             ('absorption', 'Операция поглощения'),  # 3
         ), default=0, db_index=True)
@@ -66,9 +66,9 @@ class Operations(BaseRefHierarcy):
         return IsBitOn(self.props, Operations.props.launched)
         # return True
 
-    # @property
-    # def is_partition_to_launch(self):
-    #     return IsBitOn(self.props, Operations.props.partition_to_launch)
+    @property
+    def is_grouped(self):
+        return IsBitOn(self.props, Operations.props.grouped)
 
     @property
     def is_transportation(self):
