@@ -37,7 +37,7 @@ class Ready_2_launch_detailManager(AuditManager):
 class Ready_2_launch_detail(AuditModel):
     ready = ForeignKeyCascade(Ready_2_launch)
     item_full_name = TextField(null=True, blank=True)
-    item_full_name_obj = JSONFieldIVC(default=dict)
+    item_full_name_obj = JSONFieldIVC()
     notes = TextField(null=True, blank=True)
 
     objects = Ready_2_launch_detailManager()
