@@ -246,7 +246,7 @@ class Ready_2_launch_ext:
                     # items_refs_stack.push(item_ref, lambda stack, item: len([it for it in stack if it.id != item_ref.id]) == 0)
                     items_refs_stack.push(item_ref)
 
-                    operations_cnt = Operations_item.objects.filter(item=item_ref.child).count()
+                    operations_cnt = Operations_item.objects.filter(item=item_ref.child).alive().count()
                     section = None
                     item_full_name = None
                     item_full_name_obj = None
